#################################
Appendix A: Zope Core Permissions
#################################

This is a list of standard permissions included with Zope.  It is a good
idea to use these permissions when applicable with your Zope products,
rather than creating new ones.  A list of built-in Zope permissions are
available in the `source code of the AccessControl package
<https://github.com/zopefoundation/AccessControl/blob/master/src/AccessControl/Permissions.py>`_.

Core Permissions
================

- Access contents information
- Add Database Methods
- Add Documents, Images, and Files
- Add External Methods
- Add Folders
- Add MailHost objects
- Add Page Templates
- Add Python Scripts
- Add User Folders
- Add Vocabularies
- Add Z Gadfly Database Connections
- Add ZCatalogs
- Add Zope Tutorials
- Change Database Connections
- Change Database Methods
- Change External Methods
- Change Images and Files
- Change Python Scripts
- Change configuration
- Change Page Templates
- Change permissions
- Change proxy roles
- Copy or Move
- Create class instances
- Define permissions
- Delete objects
- Edit Factories
- FTP access
- Import/Export objects
- Manage Vocabulary
- Manage ZCatalog Entries
- Manage ZCatalogIndex Entries
- Manage properties
- Manage users
- Open/Close Database Connection
- Open/Close Database Connections
- Query Vocabulary
- Search ZCatalog
- Take ownership
- Test Database Connections
- Undo changes
- Use Database Methods
- Use Factories
- Use mailhost services
- View
- View management screens
- WebDAV access
- WebDAV Lock items
- WebDAV Unlock items

Document Template Permissions
=============================

- Change DTML Documents
- Change DTML Methods
